- DOMICILE_CERTIFIED =
Quality.new(value: "DOMICILE_CERTIFIED", description: "The address, including the full name of the person, is certified by SwissPost")
- CERTIFIED =
Quality.new(value: "CERTIFIED", description: "The address is certified by the Swiss Post")
- USABLE =
Quality.new(value: "USABLE", description: "Parts of the address have been recognized and the address is considered as reusable in other contexts")
- FIXED =
Quality.new(value: "FIXED", description: "The returned address is USABLE, but some minor typos have been corrected (e.g. you sent only the zip and the SwissPost service add the city name)")
- UNUSABLE =
Quality.new(value: "UNUSABLE", description: "The system was not able to recognize an acceptable address in any field provided")
- COMPROMISED =
Quality.new(value: "COMPROMISED", description: "The address may have been modified by a man in the middle")